@@ -45,9 +45,9 @@ get_nc_meta <- function (file) {
 #' [load_cmip6_index()].
 #'
 #' `summary_database()` uses [future.apply][future.apply::future_lapply()]
-#' underneath. You can use your preferable [future][future::plan] backend to
+#' underneath. You can use your preferable future backend to
 #' speed up data extraction in parallel. By default, `summary_database()` uses
-#' [future::sequential] backend, which runs things in sequential.
+#' `future::sequential` backend, which runs things in sequential.
 #'
 #' @param dir A single string indcating the directory where CMIP6 model output
 #'        NetCDF files are stored.
@@ -188,12 +188,16 @@ summary_database <- function (
         # c) calculate the overlapped percentages coverred datetime of input
         # file to index data
         set(idx_m, NULL, "index_match", seq_len(nrow(idx_m)))
-        idx_m[, by = c("index_match"),
-            overlap := {
-                diff <- as.numeric(difftime(i.datetime_end, i.datetime_start, units = "days"))
-                sq <- seq(datetime_start, datetime_end, by = "1 day")
-                sum(sq >= i.datetime_start & sq <= i.datetime_end) / diff
-        }]
+        if (!nrow(idx_m)) {
+            set(idx_m, NULL, "overlap", double())
+        } else {
+            idx_m[, by = c("index_match"),
+                overlap := {
+                    diff <- as.numeric(difftime(i.datetime_end, i.datetime_start, units = "days"))
+                    sq <- seq(datetime_start, datetime_end, by = "1 day")
+                    sum(sq >= i.datetime_start & sq <= i.datetime_end) / diff
+            }]
+        }
 
         # d) only keep items that have overlapped percentages larger than 60%
         idx_m <- idx_m[overlap >= 0.6]
@@ -342,6 +346,29 @@ get_nc_data <- function (x, lats, lons, years, unit = TRUE) {
     dims[J("lon"), on = "name", `:=`(value = list(which_lon))]
     dims[J("lat"), on = "name", `:=`(value = list(which_lat))]
 
+    # find correct dimentions
+    ord <- list(
+        c("lon", "lat", "time"),
+        c("lat", "lon", "time"),
+        c("time", "lon", "lat"),
+        c("lat", "time", "lon"),
+        c("lon", "time", "lat"),
+        c("time", "lat", "lon")
+    )
+    ord <- ord[vapply(ord, function (i) {
+        d <- dims[J(i), on = "name"]$length
+        !is.null(tryCatch(RNetCDF::var.get.nc(nc, var, d, rep(1L, 3), collapse = FALSE),
+            error = function (e) {
+                if (grepl("exceeds dimension bound", conditionMessage(e), fixed = TRUE)) {
+                    NULL
+                } else {
+                    signalCondition(e)
+                }
+            }
+        ))
+    }, logical(1))][[1L]]
+    dims <- dims[J(ord), on = "name"]
+
     dt <- rbindlist(use.names = TRUE, lapply(seq_along(which_time), function (i) {
         if (!length(which_time[[i]])) {
             return(data.table(
@@ -357,29 +384,12 @@ get_nc_data <- function (x, lats, lons, years, unit = TRUE) {
         # Thus, the order of the dimensions according to the CDL conventions
         # (e.g., time, latitude, longitude) is reversed in the R array (e.g.,
         # longitude, latitude, time).
-        dt <- tryCatch(as.data.table(RNetCDF::var.get.nc(nc, var,
+        dt <- as.data.table(RNetCDF::var.get.nc(nc, var,
             c(min(dims$value[[1L]]), min(dims$value[[2L]]), min(dims$value[[3L]])),
             c(length(dims$value[[1L]]), length(dims$value[[2L]]), length(dims$value[[3L]])),
-            collapse = FALSE)),
-            error = function (e) {
-                if (grepl("exceeds dimension bound", conditionMessage(e), fixed = TRUE)) {
-                    NULL
-                } else {
-                    signalCondition(e)
-                }
-            }
+            collapse = FALSE)
         )
 
-        # in case permutation did not work
-        if (is.null(dt)) {
-            dims <- dims[c(3L, 2L, 1L)][, id := .I]
-            dt <- as.data.table(RNetCDF::var.get.nc(nc, var,
-                c(min(dims$value[[1L]]), min(dims$value[[2L]]), min(dims$value[[3L]])),
-                c(length(dims$value[[1L]]), length(dims$value[[2L]]), length(dims$value[[3L]])),
-                collapse = FALSE
-            ))
-        }
-
         setnames(dt, c(dims$name, "value"))
         setnames(dt, "time", "datetime")
 
@@ -417,9 +427,9 @@ get_nc_data <- function (x, lats, lons, years, unit = TRUE) {
 #' interest specified.
 #'
 #' `extract_data()` uses [future.apply][future.apply::future_lapply()]
-#' underneath. You can use your preferable [future][future::plan] backend to
+#' underneath. You can use your preferable future backend to
 #' speed up data extraction in parallel. By default, `extract_data()` uses
-#' [future::sequential] backend, which runs things in sequential.
+#' `future::sequential` backend, which runs things in sequential.
 #'
 #' @param coord An `epw_cmip6_coord` object created using [match_coord()]
 #'
